<?php
/*
Plugin Name: SlideShare
Plugin URI: http://yoast.com/wordpress/slideshare/
Description: A plugin WordPress to easily display slideshare.net presentations
Version: 1.4
Author: Joost de Valk
Author URI: http://yoast.com/
*/

if ( ! class_exists( 'SlideShare_Admin' ) ) {

	class SlideShare_Admin {

		function add_config_page() {
			global $wpdb;
			if ( function_exists('add_submenu_page') ) {
				add_options_page('SlideShare Config', 'SlideShare', 10, basename(__FILE__),array('SlideShare_Admin','config_page'));
				add_filter( 'plugin_action_links', array( 'SlideShare_Admin', 'filter_plugin_actions'), 10, 2 );
				add_filter( 'ozh_adminmenu_icon', array( 'SlideShare_Admin', 'add_ozh_adminmenu_icon' ) );				
			}
		}
		
		function add_ozh_adminmenu_icon( $hook ) {
			static $slideshareicon;
			if (!$slideshareicon) {
				$slideshareicon = WP_CONTENT_URL . '/plugins/' . plugin_basename(dirname(__FILE__)). '/page_white_powerpoint.png';
			}
			if ($hook == 'slideshare.php') return $slideshareicon;
			return $hook;
		}

		function filter_plugin_actions( $links, $file ){
			//Static so we don't call plugin_basename on every plugin row.
			static $this_plugin;
			if ( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);
			
			if ( $file == $this_plugin ){
				$settings_link = '<a href="options-general.php?page=slideshare.php">' . __('Settings') . '</a>';
				array_unshift( $links, $settings_link ); // before other links
			}
			return $links;
		}
		function config_page() {
			if ( isset($_POST['submit']) ) {
				if (!current_user_can('manage_options')) die(__('You cannot edit the SlideShare options.'));
				check_admin_referer('slideshare-updatesettings');

				if (isset($_POST['slidesharepostwidth'])) {
					$options['postwidth'] = $_POST['slidesharepostwidth'];
				}
				
				update_option('SlideShare', $options);
			}

			$options  = get_option('SlideShare');
			?>
			<div class="wrap">
				<h2>SlideShare Configuration</h2>
				<form action="" method="post" id="slideshare-conf">
					<?php if (function_exists('wp_nonce_field')) { wp_nonce_field('slideshare-updatesettings'); } ?>
					<table class="form-table">
						<tr>
							<td>
								<label for="slidesharepostwidth">Default width:</label>
							</td>
							<td>
								<input size="5" type="text" id="slidesharepostwidth" name="slidesharepostwidth" value="<?php echo $options['postwidth'];?>"/> pixels
							</td>
						</tr>
						<tr>
							<td>&nbsp;</td>
							<td>
								<span class="submit"><input type="submit" name="submit" value="Update Settings &raquo;" /></span>
							</td>
					</table>
				</form>
				<h3>Explanation of usage</h3>
				<p>
					Just copy and paste the "Embed (wordpress.com)" code from <a href="http://www.slideshare.net/" title="SlideShare (share powerpoint presentations online, slideshows, slide shows, download presentations, widgets, MySpace codes)">SlideShare</a>, and you're done.
				</p>
				<h3>Explanation of default width</h3>
				<p>
					If you enter nothing here, you can change the width by hand by changing the w= value, that is bolded and red here:
				</p>
				<pre>[slideshare id=1234&amp;doc=how-to-change-the-width-123456789-1&amp;<strong style="color:red;">w=425</strong>]</pre>
				<p>
					If you <em>do</em> enter a value, it will always replace the width with that value.
				</p>
			</div>
			<?php
		}
	}
}

function slideshare_insert($atts, $content=null) {	
	$options = get_option('SlideShare');
	
	if(isset($atts)) {
		$args			= str_replace('&amp;','&',$atts['id']);
		$r 				= wp_parse_args($args);
	
		if ($options['postwidth'] == '') {
			$width		= $r['w'];			
		} else {
			$width		= $options['postwidth'];
		}
		$height			= $width / 1.22;
		
		$content		= '<object style="margin:0px" width="'.$width.'" '.'height="'.$height.'"><param name="movie" value="http://static.slideshare.net/swf/ssplayer2.swf?doc='.$r['doc'].'"/><param name="allowFullScreen" value="true"/><param name="allowScriptAccess" value="always"/><embed src="http://static.slideshare.net/swf/ssplayer2.swf?doc='.$r['doc'].'" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" width="'.$width.'" '.'height="'.$height.'"></embed></object>';
	}
	
	return $content;
}

add_action('admin_menu', array('SlideShare_Admin','add_config_page'));
add_shortcode('slideshare', 'slideshare_insert');

?>
